@@ -61,15 +61,20 @@ class QLDBDriver:
 
         statement = f"SELECT {identifier} FROM {table_name}"
         
-        ids = self.query(statement)
+        ids_tmp = self.query(statement)
+        ids = []
 
-        for id in ids:
-            if isinstance(id[identifier], str):
-                statement = f"FROM {table_name} WHERE {identifier} = '{id[identifier]}' SET {attribute_name} = {default_value}"
-            elif isinstance(id[identifier], numbers.Number):
-                statement = f"FROM {table_name} WHERE {identifier} = {id[identifier]} SET {attribute_name} = {default_value}"
+        for id_tmp in ids_tmp:
+            ids.append(id_tmp[identifier])
 
-            self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
+        step = 40
+        
+        while len(ids) > 0:
+            statement = f"FROM {table_name} WHERE {identifier} IN {tuple(ids[:step])} SET {attribute_name} = {default_value}"
+            syslog.syslog(statement)
+
+            self.execute_statement(statement)
+            del ids[:step]
 
 
     def remove_attribute(self, table_name, identifier, attribute_name):
@@ -88,6 +93,7 @@ class QLDBDriver:
             except:
                 pass
 
+
     def list_tables(self):
         collection = []
 
